query_state

Function query_state 

pub fn query_state(name: &str) -> Result<ContainerState>
Query the state of a container.

Checks podman inspect first. If the container is unknown to podman, falls back to systemctl --user is-active (quadlet-managed containers) and returns Stopped when the unit exists but is inactive.