Module ports

Module ports 

Structs

PortConflict
A host port that is already occupied by another process.

Functions

check_host_ports
Check every published host port for an existing listener on the host.