Module systemd

Module systemd 

Structs

UnitStatus
Parsed status of a systemd unit.

Functions

daemon_reload
Run systemctl --user daemon-reload.
enable_linger
Ensure linger is enabled for the current user.
enable_now_socket
Start and enable a socket unit.
is_available
Whether systemctl is available on this system.
is_unit_enabled
Check whether a unit is enabled in systemd.
is_unit_failed
Check whether a unit is in the failed state.
journal_tail
Tail journal logs for a container’s service units.
query_unit_status
Query systemd unit properties via systemctl --user show.
reset_failed
Run systemctl --user reset-failed for a container’s units.
restart_unit
Restart a service unit via systemctl --user restart.
start_unit
Start a service unit via systemctl --user start.
start_unit_friendly
Start a container with friendly diagnostics on failure.
stop_compositor
Stop the Wayland compositor proxy service if it exists.
stop_socket_and_host
Stop socket and host service units.
stop_unit
Stop a service unit via systemctl --user stop.