is_verbose

Function is_verbose 

pub fn is_verbose() -> bool
True when any --verbose level is active. Long-running child processes (podman build/pull) stream their output to the terminal in this mode instead of being captured to the build log.