Functions
- apply_
defaults - Apply podbox label defaults to a Config, with the user config winning on every field that was explicitly set.
- fetch
- Fetch the OCI labels for a local image tag.
Type Aliases
- Label
Map - Raw OCI labels read from
podman inspect.