Structs
- Unit
Status - Parsed status of a systemd unit.
Functions
- daemon_
reload - Run
systemctl --user daemon-reload. - enable_
linger - Ensure linger is enabled for the current user.
- enable_
now_ socket - Start and enable a socket unit.
- is_
available - Whether systemctl is available on this system.
- is_
unit_ enabled - Check whether a unit is enabled in systemd.
- is_
unit_ failed - Check whether a unit is in the failed state.
- journal_
tail - Tail journal logs for a container’s service units.
- query_
unit_ status - Query systemd unit properties via
systemctl --user show. - reset_
failed - Run
systemctl --user reset-failedfor a container’s units. - restart_
unit - Restart a service unit via
systemctl --user restart. - start_
unit - Start a service unit via
systemctl --user start. - start_
unit_ friendly - Start a container with friendly diagnostics on failure.
- stop_
compositor - Stop the Wayland compositor proxy service if it exists.
- stop_
socket_ and_ host - Stop socket and host service units.
- stop_
unit - Stop a service unit via
systemctl --user stop.